# nbnorm

a convenience tool to do mass notebook normalization

initially developped for https://github.com/flotpython/course,
and initially located in https://github.com/flotpython/tools,
but substantially modified later on.
